supportsImageStreaming method
Check whether this platform supports image streaming via onStreamedFrameAvailable.
Implementation
@override
bool supportsImageStreaming() => true;
Check whether this platform supports image streaming via onStreamedFrameAvailable.
@override
bool supportsImageStreaming() => true;