HostCameraMessageHandler class

Handles camera-specific callbacks from the platform host.

Annotations

Constructors

HostCameraMessageHandler(int cameraId, StreamController<CameraEvent> cameraEventStreamController)
Creates a new handler and registers it to listen to its camera's platform channel.

Properties

cameraEventStreamController StreamController<CameraEvent>
The controller which broadcasts camera events from the host platform.
final
cameraId int
The ID of the camera for which this handler listens for events.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

closed() → void
Called when the camera closes.
dispose() → void
Removes this handler from its platform channel.
error(String message) → void
Called when an error occurs in the camera.
initialized(PlatformCameraState initialState) → void
Called when the camera is initialized.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited