cameraEventStreamController property
The controller which broadcasts camera events from the host platform.
Implementation
final StreamController<CameraEvent> cameraEventStreamController;
The controller which broadcasts camera events from the host platform.
final StreamController<CameraEvent> cameraEventStreamController;