HostDeviceMessageHandler class

Handles callbacks from the platform host that are not camera-specific.

Annotations

Constructors

HostDeviceMessageHandler()
Creates a new handler and registers it to listen to the global event platform channel.

Properties

deviceEventStreamController StreamController<DeviceEvent>
The controller that broadcasts device events coming from the host platform.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

deviceOrientationChanged(PlatformDeviceOrientation orientation) → void
Called when the device's physical orientation changes.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited